@@ -332,53 +332,6 @@ class Server(intp: IMain, sockets: Sockets, referenceMap: HashMap[Int, (Any,Stri
     }
   }
 
-  private def addToClasspath(): Unit = {
-    if ( debugger.on ) debugger("add to classpath.")
-    val file = new File(readString)
-    try {
-      intp.addUrlsToClassPath(file.toURI.toURL)
-    } catch {
-      case _: Throwable =>
-        if ( debugger.on ) debugger("Problem adding JAR to classpath.  Perhaps we hit this bug: https://github.com/scala/bug/issues/11565.")
-        try {  // This is work-around for the bug that I reported here https://github.com/scala/bug/issues/11565
-          // Since the deleteOnExit (below) doesn't work on Windows, at least we can clean up from previous instances.
-          val filenameFilter = new FilenameFilter {
-            override def accept(directory: File, name: String): Boolean = {
-              name.startsWith("bug11565-") && name.endsWith(".jar")
-            }
-          }
-          val (oldFiles, tmpDir) = {
-            val y = new File(if ( ! scala.util.Properties.isWin ) "/tmp" else sys.env("SystemRoot") + File.separator + "Temp")
-            val x = y.listFiles(filenameFilter)
-            if ((x == null) && scala.util.Properties.isWin) {
-              val y2 = new File(sys.env("SystemDrive") + File.separator + "bug11565")
-              y2.mkdirs()
-              (y2.listFiles(filenameFilter), y2)
-            } else (x, y)
-          }
-          oldFiles.map { file =>
-            try {
-              file.delete()
-            } catch {
-              case _: Throwable =>
-            }
-          }
-          val tempFile = File.createTempFile("bug11565-",".jar", tmpDir)
-          java.nio.file.Files.copy(file.toPath,tempFile.toPath,java.nio.file.StandardCopyOption.REPLACE_EXISTING)
-          tempFile.deleteOnExit()   // This doesn't work on Windows because the JVM keeps the file open.
-          intp.addUrlsToClassPath(tempFile.toURI.toURL)
-        } catch {
-          case e: Throwable =>
-            prntWrtr.println(e)
-            e.printStackTrace(prntWrtr)
-            if (debugger.on) debugger("error in adding to classpath.")
-            pop(Datum(e, TCODE_ERROR_INVOKE, None))
-            return
-        }
-    }
-    pop(Datum((),TCODE_UNIT,None))
-  }
-
   private def gc(): Unit = {
     if ( debugger.on ) debugger("garbage collect.")
     (0 until in.readInt()).foreach { i =>
@@ -426,7 +379,6 @@ class Server(intp: IMain, sockets: Sockets, referenceMap: HashMap[Int, (Any,Stri
       case PCODE_INVOKE => invoke(false, false)
       case PCODE_INVOKE_WITH_REFERENCE => invoke(true,false)
       case PCODE_INVOKE_FREEFORM => invoke(false,true)
-      case PCODE_ADD_TO_CLASSPATH => addToClasspath()
       case PCODE_GARBAGE_COLLECT => gc()
       case PCODE_SUSPEND => suspend()
       case _ =>
