@@ -9,7 +9,7 @@
 #' scalaVersionJARs()
 #' 
 scalaVersionJARs <- function() {
-  pkgHome <- if ( Sys.getenv("RSCALA_BUILDING") != "" ) file.path(getwd(),"inst") else find.package("rscala")
+  pkgHome <- if ( identical(Sys.getenv("R_INSTALL_PKG"),"rscala") ) file.path(Sys.getenv("R_PACKAGE_DIR"),"inst") else find.package("rscala")
   majorVersions <- gsub("^scala-(.*)","\\1",list.dirs(file.path(pkgHome,"java"),full.names=FALSE,recursive=FALSE))
   if ( length(majorVersions) == 0 ) return(character(0))
   result <- sapply(majorVersions, function(v) list.files(file.path(pkgHome,"java",paste0("scala-",v)),full.names=TRUE))
